@@ -22,6 +22,8 @@ from typing import (
 
 import fsspec
 import networkx as nx
+from networkx.algorithms.cycles import simple_cycles
+from networkx.algorithms.isolate import isolates
 from networkx.readwrite.json_graph import node_link_data, node_link_graph
 
 from .exceptions import DuplicateError, NodeNotFound
@@ -84,8 +86,16 @@ class NXOntology(Freezable, Generic[Node]):
         self._node_info_cache: Dict[Node, Node_Info[Node]] = {}
 
     def check_is_dag(self) -> None:
-        if not nx.is_directed_acyclic_graph(self.graph):
-            raise ValueError("NXOntology requires a directed acyclic graph.")
+        if nx.is_directed_acyclic_graph(self.graph):
+            return
+        # show at most 5 cycles to keep stderr manageable
+        cycles = itertools.islice(simple_cycles(self.graph), 5)
+        cycles_str = "\n".join(
+            " --> ".join(str(n) for n in [*cycle, cycle[0]]) for cycle in cycles
+        )
+        raise ValueError(
+            f"NXOntology requires a directed acyclic graph. Cycles found:\n{cycles_str}"
+        )
 
     @property
     def name(self) -> Optional[str]:
@@ -145,12 +155,10 @@ class NXOntology(Freezable, Generic[Node]):
     @cache_on_frozen
     def roots(self) -> Set[Node]:
         """
-        Return all top-level nodes.
+        Return all top-level nodes, including isolates.
         """
         roots = set()
         for node in self.graph.nodes():
-            if self.graph.out_degree(node) == 0:
-                continue
             if self.graph.in_degree(node) == 0:
                 roots.add(node)
         return roots
@@ -159,16 +167,22 @@ class NXOntology(Freezable, Generic[Node]):
     @cache_on_frozen
     def leaves(self) -> Set[Node]:
         """
-        Return all bottom-level nodes.
+        Return all bottom-level nodes, including isolates.
         """
         leaves = set()
         for node in self.graph.nodes():
-            if self.graph.in_degree(node) == 0:
-                continue
             if self.graph.out_degree(node) == 0:
                 leaves.add(node)
         return leaves
 
+    @property  # type: ignore [misc]
+    @cache_on_frozen
+    def isolates(self) -> Set[Node]:
+        """
+        Return disconnected nodes.
+        """
+        return set(isolates(self.graph))
+
     def freeze(self) -> None:
         """
         Modify graph to prevent further change by adding or removing nodes or edges.
@@ -237,7 +251,16 @@ class NXOntology(Freezable, Generic[Node]):
         """
         Total number of nodes in the graph.
         """
-        return len(self.graph)
+        # int wrapper is solely to satisfy mypy
+        return int(self.graph.number_of_nodes())
+
+    @property
+    def n_edges(self) -> int:
+        """
+        Total number of edges in the graph.
+        """
+        # int wrapper is solely to satisfy mypy
+        return int(self.graph.number_of_edges())
 
     def set_graph_attributes(
         self,
@@ -432,7 +455,7 @@ class Node_Info(Freezable, Generic[Node]):
         # ic_sanchez: Definition 4 / Equation 10 from https://doi.org/10.1016/j.knosys.2010.10.001
         all_leaves = self.nxo.leaves
         leaves = all_leaves & self.descendants
-        # replace negative sign with math.abs to avoid returning -0.0.
+        # replace negative sign with abs to avoid returning -0.0.
         return abs(
             math.log((len(leaves) / self.n_ancestors + 1) / (len(all_leaves) + 1))
         )
@@ -525,7 +548,8 @@ class Similarity(Freezable, Generic[Node]):
         """
         if self.batet == 1.0:
             return 1.0
-        return -math.log(1 - self.batet) / math.log(self.n_union_ancestors)
+        # replace negative sign with abs to avoid returning -0.0.
+        return abs(math.log(1 - self.batet) / math.log(self.n_union_ancestors))
 
     def results(self, keys: Optional[List[str]] = None) -> Dict[str, Any]:
         if keys is None:
